Update to 3.2.7

This commit is contained in:
Sandro Mani 2015-11-05 17:15:44 +01:00
parent 882c9ccb5d
commit 0f8ef3afc2
4 changed files with 9 additions and 41 deletions

1
.gitignore vendored
View File

@ -12,3 +12,4 @@
/eigen-3.2.4.tar.bz2 /eigen-3.2.4.tar.bz2
/eigen-3.2.5.tar.bz2 /eigen-3.2.5.tar.bz2
/eigen-3.2.6.tar.bz2 /eigen-3.2.6.tar.bz2
/eigen-3.2.7.tar.bz2

View File

@ -1,33 +0,0 @@
diff -rupN eigen-eigen-36fd1ba04c12/Eigen/src/CholmodSupport/CholmodSupport.h eigen-eigen-36fd1ba04c12-new/Eigen/src/CholmodSupport/CholmodSupport.h
--- eigen-eigen-36fd1ba04c12/Eigen/src/CholmodSupport/CholmodSupport.h 2014-12-16 18:30:52.000000000 +0100
+++ eigen-eigen-36fd1ba04c12-new/Eigen/src/CholmodSupport/CholmodSupport.h 2014-12-17 23:35:28.080925651 +0100
@@ -78,7 +78,7 @@ cholmod_sparse viewAsCholmod(SparseMatri
{
res.itype = CHOLMOD_INT;
}
- else if (internal::is_same<_Index,UF_long>::value)
+ else if (internal::is_same<_Index,SuiteSparse_long>::value)
{
res.itype = CHOLMOD_LONG;
}
diff -rupN eigen-eigen-36fd1ba04c12/Eigen/src/SPQRSupport/SuiteSparseQRSupport.h eigen-eigen-36fd1ba04c12-new/Eigen/src/SPQRSupport/SuiteSparseQRSupport.h
--- eigen-eigen-36fd1ba04c12/Eigen/src/SPQRSupport/SuiteSparseQRSupport.h 2014-12-16 18:30:52.000000000 +0100
+++ eigen-eigen-36fd1ba04c12-new/Eigen/src/SPQRSupport/SuiteSparseQRSupport.h 2014-12-17 23:35:28.063925342 +0100
@@ -47,7 +47,7 @@ namespace Eigen {
* You can then apply it to a vector.
*
* R is the sparse triangular factor. Use matrixQR() to get it as SparseMatrix.
* NOTE : The Index type of R is always UF_long. You can get it with SPQR::Index
*
* \tparam _MatrixType The type of the sparse matrix A, must be a column-major SparseMatrix<>
* NOTE
@@ -59,7 +59,7 @@ class SPQR
public:
typedef typename _MatrixType::Scalar Scalar;
typedef typename _MatrixType::RealScalar RealScalar;
- typedef UF_long Index ;
+ typedef SuiteSparse_long Index ;
typedef SparseMatrix<Scalar, ColMajor, Index> MatrixType;
typedef PermutationMatrix<Dynamic, Dynamic> PermutationType;
public:

View File

@ -4,10 +4,10 @@
# debuginfo package for the empty main package. # debuginfo package for the empty main package.
%global debug_package %{nil} %global debug_package %{nil}
%global commit c58038c56923 %global commit b30b87236a1b
Name: eigen3 Name: eigen3
Version: 3.2.6 Version: 3.2.7
Release: 1%{?dist} Release: 1%{?dist}
Summary: A lightweight C++ template library for vector and matrix math Summary: A lightweight C++ template library for vector and matrix math
@ -18,11 +18,9 @@ URL: http://eigen.tuxfamily.org/index.php?title=Main_Page
# Renamed source file so it's not just a version number # Renamed source file so it's not just a version number
Source0: eigen-%{version}.tar.bz2 Source0: eigen-%{version}.tar.bz2
# Fix build with recent suitesparse versions
Patch0: eigen-3.2.3_suitesparse.patch
# Install FindEigen3.cmake # Install FindEigen3.cmake
# Adapted from Debian eigen3 package # Adapted from Debian eigen3 package
Patch1: 01_install_FindEigen3.patch Patch0: 01_install_FindEigen3.patch
BuildRequires: atlas-devel BuildRequires: atlas-devel
BuildRequires: fftw-devel BuildRequires: fftw-devel
@ -65,7 +63,6 @@ Developer documentation for Eigen.
%prep %prep
%setup -q -n eigen-eigen-%{commit} %setup -q -n eigen-eigen-%{commit}
%patch0 -p1 %patch0 -p1
%patch1 -p1
%build %build
mkdir %{_target_platform} mkdir %{_target_platform}
@ -102,7 +99,10 @@ make -C %{_target_platform} %{?_smp_mflags} test ARGS="-V" || exit 0
%doc %{_target_platform}/doc/html %doc %{_target_platform}/doc/html
%changelog %changelog
* Thu Oct 02 2015 Sandro Mani <manisandro@gmail.com> - 3.2.6-1 * Thu Nov 05 2015 Sandro Mani <manisandro@gmail.com> - 3.2.7-1
- Update to release 3.2.7
* Thu Oct 01 2015 Sandro Mani <manisandro@gmail.com> - 3.2.6-1
- Update to release 3.2.6 - Update to release 3.2.6
* Fri Aug 21 2015 Rich Mattes <richmattes@gmail.com> - 3.2.5-2 * Fri Aug 21 2015 Rich Mattes <richmattes@gmail.com> - 3.2.5-2

View File

@ -1 +1 @@
87274966745d2d3e7964fcc654d0a24b eigen-3.2.6.tar.bz2 cc1bacbad97558b97da6b77c9644f184 eigen-3.2.7.tar.bz2
@@ -47,7 +47,7 @@ namespace Eigen {
*
* R is the sparse triangular factor. Use matrixQR() to get it as SparseMatrix.
- * NOTE : The Index type of R is always UF_long. You can get it with SPQR::Index
+ * NOTE : The Index type of R is always SuiteSparse_long. You can get it with SPQR::Index
*
* \tparam _MatrixType The type of the sparse matrix A, must be a column-major SparseMatrix<>